YARP 2.2.1 (2008-07-08)                                                {#v2_2_1}
=======================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.2.0...v2.2.1`):

```
    55	Paul Fitzpatrick <paulfitz@alum.mit.edu>
    11	Lorenzo Natale <lorenzo.natale@iit.it>
     7	YARP Developers <yarp0-devel@lists.sourceforge.net>
     5	Giacomo Spigler <spiglerg@gmail.com>
     3	Alessandro Scalzo <alessandro.scalzo@iit.it>
     1	Giorgio Metta <giorgio.metta@iit.it>
```
